pub struct AnyTimer<'d>(/* private fields */);Expand description
Any Timer peripheral.
A type-erased version of a peripheral singleton. Useful
for creating arrays of peripherals, or avoiding generics. Peripheral singletons
can be type erased by using their From implementation.
ⓘ
let any_peripheral = AnyTimer::from(peripheral);Implementations
Sourceimpl AnyTimer<'_>
impl AnyTimer<'_>
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub fn reborrow(&mut self) -> AnyTimer<'_>
pub fn reborrow(&mut self) -> AnyTimer<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method to keep working with the peripheral after dropping the driver that consumes this.
See Peripheral singleton section for more information.
Sourcepub fn downcast<P>(self) -> Result<P, Self>where
Self: TryInto<P, Error = Self>,
pub fn downcast<P>(self) -> Result<P, Self>where
Self: TryInto<P, Error = Self>,
Attempts to downcast the pin into the underlying peripheral instance.
Example
// let peri0 = peripherals.PERI0;
// let peri1 = peripherals.PERI1;
let any_peri0 = AnyPeripheral::from(peri0);
let any_peri1 = AnyPeripheral::from(peri1);
let uart0 = any_peri0
.downcast::<PERI0>()
.expect("This downcast succeeds because AnyPeripheral was created from Peri0");
let uart0 = any_peri1
.downcast::<PERI0>()
.expect_err("This AnyPeripheral was created from Peri1, it cannot be downcast to Peri0");Trait Implementations
Sourceimpl Timer for AnyTimer<'_>
Available on crate feature unstable only.
impl Timer for AnyTimer<'_>
Available on crate feature
unstable only.Sourcefn clear_interrupt(&self)
fn clear_interrupt(&self)
Clears the timer’s interrupt.
Sourcefn is_interrupt_set(&self) -> bool
fn is_interrupt_set(&self) -> bool
Returns whether the timer has triggered.
Sourcefn peripheral_interrupt(&self) -> Interrupt
fn peripheral_interrupt(&self) -> Interrupt
Returns the interrupt source for the underlying timer.